blaze_version: The version of Blaze used in RcppBlaze

View source: R/RcppExports.R

blaze_versionR Documentation

The version of Blaze used in RcppBlaze

Description

To return the version of Blaze used in RcppBlaze.

Usage

blaze_version(single)

Arguments

single

A logical value indicates which type to return. If TRUE, it returns an integer. If FALSE, it returns a named vector.

Value

A number or a named vector to represent the version of blaze depending on the input, single.

See Also

Blaze header file blaze/system/Version.h.

Examples

blaze_version(FALSE)

RcppBlaze documentation built on Feb. 23, 2026, 5:06 p.m.